==> tine20-allinone_2020.08.8.tar.bz2: Crm/js/Crm-lang-sv_SE-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Crm **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Swedish (Sweden) (http://www.transifex.com/tine20/tine20/language/sv_SE/)\nLanguage: sv_SE\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "All leads"
: "Alla leads"

, "Default Lead List"
: "Standard projectledarlista"

, "The default list for new leads"
: "Standardlistan för nya projektledare"

, "Get Notification E-mails"
: ""

, "The level of actions you want to be notified about."
: "Nivån på åtgärder som du vill bli informerad om."

, "Send Notifications e-mails for own actions"
: ""

, "Get notifications e-mails for actions you did yourself"
: ""

, "Send Notifications e-mails to responsible"
: ""

, "Get notifications e-mails for action to responsible"
: ""

, "Send Notifications e-mails to customer"
: ""

, "Get notifications e-mails for action to customer"
: ""

, "Send Notifications e-mails to partner"
: ""

, "Get notifications e-mails for action to partner"
: ""

, "Default Favorite"
: "Standard Favorit"

, "The default favorite which is loaded on crm startup"
: "Standard favoriten som laddas på crm start"

, "New Lead"
: "Ny Lead"

, "Tags"
: "Taggar"

, "Lead name"
: "Lead Namn"

, "Responsible"
: "Ansvarig"

, "Partner"
: "Partner"

, "Customer"
: "Kund"

, "Leadstate"
: "Leadstatus"

, "Leadtype"
: "Leadtyp"

, "Leadsource"
: "Leadkälla"

, "Probability"
: "sannolikt"

, "Turnover"
: "omsättning"

, "Estimated end"
: "beräknat slut"

, "Probable Turnover"
: "Trolig Omsättning"

, "Resubmission Date"
: ""

, "Import leads"
: ""

, "Contact"
: "Kontakt"

, "CRM Role"
: "CRM Roll"

, "Tasks"
: "Uppgifter"

, "No Tasks to display"
: "Inga uppgifter att visa"

, "Summary"
: "sammanfattning"

, "Add a task..."
: "Lägg till en uppgift ..."

, "Due Date"
: "Förfallo Datum"

, "Priority"
: "Prioritet"

, "Percent"
: "procent"

, "Status"
: "Status"

, "Organizer"
: ""

, "Add new {0}"
: "Lägg till ny {0}"

, "Unlink {0}"
: "Avlänka {0}"

, "Unlink selected {0}"
: "Avlänk {0}"

, "Edit {0}"
: "Redigera {0}"

, "Edit selected {0}"
: "Redigering valt {0}"

, "Please choose the Lead to add the contacts to"
: "Välj Lead till att lägga till kontakter till"

, "Please select the attenders' role"
: "Välj deltagarnas roll"

, "Lead, Leads"
: [
  "Lead"
 ,"Leads"

]
, "Select Lead"
: "Välj Lead"

, "Role"
: "Roll"

, "Select Role"
: "Välj Roll"

, "Adding {0} contacts to lead"
: "Lägger till {0} kontakter som projektledare"

, "Phone"
: "Telefon"

, "Mobile"
: "Mobil"

, "Fax"
: "Fax"

, "E-Mail"
: "E-post"

, "Web"
: "Webb"

, "Street"
: ""

, "Postalcode"
: ""

, "City"
: ""

, "Start"
: "Start"

, "Change type to Customer"
: "Ändra typ till kund"

, "Change type to Responsible"
: "Ändra typ till Ansvarig"

, "Change type to Partner"
: "Ändra typ till Partner"

, "Change contact type"
: "Ändra kontakt typ"

, "Search for Contacts to add ..."
: "Sök på kontakter att lägga till ..."

, "Name"
: "namn"

, "Address"
: "Adress"

, "Data"
: "Data"

, "Cellphone"
: "Mobiltelefon"

, "End"
: "Slut"

, "You do not have the run right for the Tasks application or it is not activated."
: "Du har inte kör rättigheter för Uppgifts applikation eller är det inte aktiverat"

, "Products"
: "Produkter"

, "You do not have the run right for the Sales application or it is not activated."
: "Du har inte kör rättigheter för Sälj applikatio så är det inte aktiverat."

, "Enter lead name"
: ""

, "Expected turnover"
: "Förväntad omsättning"

, "Description"
: "Beskrivning"

, "Enter description"
: "Skriv beskrivning"

, "lead list, lead lists"
: [
  "lead lista"
 ,"lead listor"

]
, "lead lists"
: "lead listor"

, "Quick Search"
: ""

, "Last Modified Time"
: "Senast ändrad"

, "Last Modified By"
: "Senast ändrad av"

, "Creation Time"
: "Skapad Tid"

, "Created By"
: "Skapad av"

, "X Lead"
: ""

, "Archived"
: ""

, "Product"
: "Produkt"

, "Price"
: "Pris"

, "Quantity"
: "kvantitet"

, "Search for Products to add ..."
: "Sök på produkter att lägga till ..."

, "All leads I have read grants for"
: "Alla leads Jag har läs rättigheter för"

, "Last modified by me"
: "Senast uppdaterad av mig"

, "All leads that I have last modified"
: "Alla leads jag senast har modifierat"

, "My leads"
: "Mina leads"

, "All leads that I am responsible for"
: "Alla leads som jag är ansvarig för"

, "Leads with overdue tasks"
: "Leads med förfallna arbetsuppgifter"

, "Lead States Available"
: ""

, "Possible lead status, with their associated turnover probabilities. If a status is flagged, leads with this status are treated as closed."
: ""

, "open"
: "Öppna"

, "contacted"
: "Kontaktad"

, "waiting for feedback"
: "väntar på feedback"

, "quote sent"
: "citera skickat"

, "accepted"
: "Godkännd"

, "lost"
: "Förlorad"

, "Lead Sources Available"
: ""

, "Possible lead sources. If a source is flagged as archived, leads of this source are treated as closed."
: ""

, "Lead Types Available"
: ""

, "Possible lead types."
: ""

, "Reseller"
: "återförsäljare"

, "Enabled Features"
: ""

, "Enabled Features in CRM Application."
: ""

, "Lead Import"
: ""

, "Add new task on lead import"
: ""

, "Automatically creates a task for the responsible person if a new lead is imported."
: ""

, "Send notification e-mail on lead import"
: ""

, "Sends an e-mail to all responsible persons for the imported leads."
: ""

, "Lead duplicate check fields"
: ""

, "These fields are checked when a new lead is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: ""

, "State"
: "tillstånd"

, "Source"
: "Källa"

, "Scheduled end"
: "Schemalagt slut"

, "Folder"
: "Mapp"

, "Updated by"
: "Uppdaterad av"

, "Updated Fields:"
: "Uppdaterade Fält:"

, "'%s' changed from '%s' to '%s'."
: ""

, "Lead %s has been changed"
: "Lead %s har ändrats"

, "Lead %s has been deleted"
: ""

, "Lead %s has been created"
: "Lead %s har skapats"

, "Task"
: ""

, "Lead Data"
: "Lead Data"

, "End Scheduled"
: "avsluta Schemalagd"

, "Contacts"
: "Kontakter"

, "Telephone"
: "Telefon"

, "Email"
: "E-post"

, "low"
: "Låg"

, "normal"
: "Normal"

, "high"
: "Hög"

, "urgent"
: "Viktig"

, "Lead CSV import"
: ""

, "Import list (###CURRENTDATE###)"
: ""

, "Leads imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: ""

, "Edit new lead"
: ""

, "The following leads have just been imported into lead list %s"
: ""

, "%s new leads have been imported"
: ""

, "manage shared lead folders"
: "hantera delade lead mappar"

, "Create new shared lead folders"
: "Skapa nya delade lead mappar"

, "manage shared leads favorites"
: "hantera delade leads favoriter"

, "Create or update shared leads favorites"
: "Skapa eller uppdatera delade leads favoriter"




, "Lead"
: "Lead"

, "lead list"
: "lead lista"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: Crm/js/Crm-lang-sv_SE-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Crm **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:49+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Swedish (Sweden) (http://www.transifex.com/tine20/tine20/language/sv_SE/)\nLanguage: sv_SE\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Customer"
: "Kund"

, "Partner"
: "Partner"

, "Phone"
: "Telefon"

, "Mobile"
: "Mobil"

, "Fax"
: "Fax"

, "E-Mail"
: "E-post"

, "Web"
: "Webb"

, "Street"
: ""

, "Postalcode"
: ""

, "City"
: ""

, "Status"
: "Status"

, "Start"
: "Start"

, "Estimated end"
: "beräknat slut"

, "Leadtype"
: "Leadtyp"

, "Leadsource"
: "Leadkälla"

, "Tags"
: "Taggar"

, "Lead name"
: "Lead Namn"

, "Responsible"
: "Ansvarig"

, "Leadstate"
: "Leadstatus"

, "Probability"
: "sannolikt"

, "Turnover"
: "omsättning"

, "End"
: "Slut"

, "Probable Turnover"
: "Trolig Omsättning"

, "Resubmission Date"
: ""

, "Import leads"
: ""

, "Add new {0}"
: "Lägg till ny {0}"

, "Unlink {0}"
: "Avlänka {0}"

, "Unlink selected {0}"
: "Avlänk {0}"

, "Edit {0}"
: "Redigera {0}"

, "Edit selected {0}"
: "Redigering valt {0}"

, "New Lead"
: "Ny Lead"

, "Products"
: "Produkter"

, "Product"
: "Produkt"

, "Description"
: "Beskrivning"

, "Price"
: "Pris"

, "Quantity"
: "kvantitet"

, "Search for Products to add ..."
: "Sök på produkter att lägga till ..."

, "1"
: ""

, "Notifications are disabled"
: ""

, "Send Notification?"
: ""

, "Changes to this lead might send notifications. Press the button \"Notifcation are enabled\" to switch to \"Notification are disabled\""
: ""

, "Tasks"
: "Uppgifter"

, "You do not have the run right for the Tasks application or it is not activated."
: "Du har inte kör rättigheter för Uppgifts applikation eller är det inte aktiverat"

, "You do not have the run right for the Sales application or it is not activated."
: "Du har inte kör rättigheter för Sälj applikatio så är det inte aktiverat."

, "Lead, Leads"
: [
  "Lead"
 ,"Leads"

]
, "Enter lead name"
: ""

, "Expected turnover"
: "Förväntad omsättning"

, "Enter description"
: "Skriv beskrivning"

, "lead list, lead lists"
: [
  "lead lista"
 ,"lead listor"

]
, "lead lists"
: "lead listor"

, "Quick Search"
: ""

, "Last Modified Time"
: "Senast ändrad"

, "Last Modified By"
: "Senast ändrad av"

, "Creation Time"
: "Skapad Tid"

, "Created By"
: "Skapad av"

, "X Lead"
: ""

, "read-only"
: ""

, "Archived"
: ""

, "Contact"
: "Kontakt"

, "CRM Role"
: "CRM Roll"

, "Change type to Customer"
: "Ändra typ till kund"

, "Change type to Responsible"
: "Ändra typ till Ansvarig"

, "Change type to Partner"
: "Ändra typ till Partner"

, "Change contact type"
: "Ändra kontakt typ"

, "Search for Contacts to add ..."
: "Sök på kontakter att lägga till ..."

, "Name"
: "namn"

, "Address"
: "Adress"

, "Data"
: "Data"

, "Cellphone"
: "Mobiltelefon"

, "Role"
: "Roll"

, "Please choose the Lead to add the contacts to"
: "Välj Lead till att lägga till kontakter till"

, "Please select the attenders' role"
: "Välj deltagarnas roll"

, "Select Lead"
: "Välj Lead"

, "Select Role"
: "Välj Roll"

, "Adding {0} contacts to lead"
: "Lägger till {0} kontakter som projektledare"

, "No Tasks to display"
: "Inga uppgifter att visa"

, "Summary"
: "sammanfattning"

, "Add a task..."
: "Lägg till en uppgift ..."

, "Due Date"
: "Förfallo Datum"

, "Priority"
: "Prioritet"

, "Percent"
: "procent"

, "Organizer"
: ""

, "All leads"
: "Alla leads"

, "Default Lead List"
: "Standard projectledarlista"

, "The default list for new leads"
: "Standardlistan för nya projektledare"

, "Get Notification E-mails"
: ""

, "The level of actions you want to be notified about."
: "Nivån på åtgärder som du vill bli informerad om."

, "Send Notifications e-mails for own actions"
: ""

, "Get notifications e-mails for actions you did yourself"
: ""

, "Default Favorite"
: "Standard Favorit"

, "The default favorite which is loaded on crm startup"
: "Standard favoriten som laddas på crm start"

, "controls sending notification of Leads"
: ""

, "send notification)description"
: ""

, "send notification to all access container"
: ""

, "send notification to responsible"
: ""

, "send notification to responsible)description"
: ""

, "send notification to customer"
: ""

, "send notification to partner"
: ""

, "Lead States Available"
: ""

, "Possible lead status, with their associated turnover probabilities. If a status is flagged, leads with this status are treated as closed."
: ""

, "open"
: "Öppna"

, "contacted"
: "Kontaktad"

, "waiting for feedback"
: "väntar på feedback"

, "quote sent"
: "citera skickat"

, "accepted"
: "Godkännd"

, "lost"
: "Förlorad"

, "Lead Sources Available"
: ""

, "Possible lead sources. If a source is flagged as archived, leads of this source are treated as closed."
: ""

, "Lead Types Available"
: ""

, "Possible lead types."
: ""

, "Reseller"
: "återförsäljare"

, "Enabled Features"
: ""

, "Enabled Features in CRM Application."
: ""

, "Lead Import"
: ""

, "Lead Notification Confirmation"
: ""

, "Add new task on lead import"
: ""

, "Automatically creates a task for the responsible person if a new lead is imported."
: ""

, "Send notification e-mail on lead import"
: ""

, "Sends an e-mail to all responsible persons for the imported leads."
: ""

, "Lead duplicate check fields"
: ""

, "These fields are checked when a new lead is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: ""

, "Lead Data"
: "Lead Data"

, "End Scheduled"
: "avsluta Schemalagd"

, "Contacts"
: "Kontakter"

, "Telephone"
: "Telefon"

, "Email"
: "E-post"

, "low"
: "Låg"

, "normal"
: "Normal"

, "high"
: "Hög"

, "urgent"
: "Viktig"

, "CSV all data"
: ""

, "Lead CSV import"
: ""

, "Import list (###CURRENTDATE###)"
: ""

, "Leads imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: ""

, "Edit new lead"
: ""

, "The following leads have just been imported into lead list %s"
: ""

, "%s new leads have been imported"
: ""

, "GENDER_Lead"
: ""

, "Show Closed"
: ""

, "Task"
: ""

, "State"
: "tillstånd"

, "Source"
: "Källa"

, "Scheduled end"
: "Schemalagt slut"

, "Folder"
: "Mapp"

, "Updated by"
: "Uppdaterad av"

, "Updated Fields:"
: "Uppdaterade Fält:"

, "'%s' changed from '%s' to '%s'."
: ""

, "Lead %s has been changed"
: "Lead %s har ändrats"

, "Lead %s has been deleted"
: ""

, "Lead %s has been created"
: "Lead %s har skapats"

, "This Lead state is set to read-only therefore updating this Lead is not possible."
: ""

, "All leads I have read grants for"
: "Alla leads Jag har läs rättigheter för"

, "Last modified by me"
: "Senast uppdaterad av mig"

, "All leads that I have last modified"
: "Alla leads jag senast har modifierat"

, "My leads"
: "Mina leads"

, "All leads that I am responsible for"
: "Alla leads som jag är ansvarig för"

, "Leads with overdue tasks"
: "Leads med förfallna arbetsuppgifter"

, "manage shared lead folders"
: "hantera delade lead mappar"

, "Create new shared lead folders"
: "Skapa nya delade lead mappar"

, "manage shared leads favorites"
: "hantera delade leads favoriter"

, "Create or update shared leads favorites"
: "Skapa eller uppdatera delade leads favoriter"




, "Lead"
: "Lead"

, "lead list"
: "lead lista"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
